#
# spec file for package guake
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           guake
Version:        3.2.1
Release:        lp150.1.1
Summary:        Drop-down terminal for GNOME
License:        GPL-2.0-only
Group:          System/X11/Terminals
Url:            http://guake-project.org/
Source:         https://github.com/Guake/guake/archive/%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gettext-tools
BuildRequires:  glib2-tools
BuildRequires:  gobject-introspection
BuildRequires:  pandoc
BuildRequires:  python3-pbr
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       python3-cairo
Requires:       python3-dbus-python
Requires:       python3-pbr
Recommends:     libutempter0
Suggests:       gtk3-metatheme-numix
BuildArch:      noarch
# Other requirements documented upstream but apparently not needed:
#     dconf-editor
#     glade
#     gnome-tweak-tool
#     gsettings-desktop-schemas

%description
Guake is a dropdown terminal made for the GNOME desktop environment.

%prep
%setup -q

%build
make

%install
PBR_VERSION=%{version} make install DESTDIR=%{buildroot} prefix=%{_prefix}
rm -r %{buildroot}%{python3_sitelib}/guake/tests/
# conflicts with libgio-2_0-0
rm %{buildroot}%{_datadir}/glib-2.0/schemas/gschemas.compiled
%fdupes %{buildroot}
%suse_update_desktop_file -G "Guake Preferences" %{name}-prefs Settings DesktopSettings
%suse_update_desktop_file -G "Guake Terminal" %{name} System TerminalEmulator
%find_lang %{name}

%files -f %{name}.lang
%doc README.rst NEWS.rst
%license COPYING
%{python3_sitelib}/*
%{_bindir}/guake
%{_datadir}/applications/guake-prefs.desktop
%{_datadir}/applications/guake.desktop
%{_datadir}/glib-2.0/schemas/org.guake.gschema.xml
%{_datadir}/pixmaps/
%{_datadir}/guake/

%changelog
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 3.2.1:
  * Introduce Nord: a new nice, clean new palette theme is
    available for Guake users (gh#Guake/guake#1275)
  * Fix duplication in theme list (gh#Guake/guake#1304)
  * Fix right click selection in Midnight Commander
  * Corrected usage of Vte.Regex.new_for_match to fix regular
    expression matching (hyperlinks, quick open) on VTE >0.50
    (gh#Guake/guake#1295). URL with ' (simple quote) and ()
    (parenthesis) are now captured by hyperlink matcher. User can
    still select the URL in the terminal if he wishes to capture
    the exact url, before doing a Ctrl+click or a right click.
  * Fix "Grubbox Dark" theme
  * Updated translations.
- Changes from version 3.2.0:
  * Allow user to select the theme within the preference UI
  * Selected tab use "selected highlight" color from theme
    (gh#Guake/guake##1036)
  * Updated translations.
* Mon Apr 16 2018 sebix+novell.com@sebix.at
- Use gobject-introspection for typelib library detection.
* Sat Apr 14 2018 sebix+novell.com@sebix.at
- update to version 3.1.1:
  * New Features
  * Quick open displays a combobox with predefined settings for Visual Studio Code, Atom and Sublime Text.
  * Bug Fixes
  * Fix hyperlink VTE
- update to version 3.1.0:
  * Release Summary
  * This version of Guake brings mostly bug fixes, and some new features like "Quick Open on selection".
    I have also reworked internally the Quick Open so that it can automatically open files from logs
    from pytest and other python development tools output. However, there might still some false
    positive on the hovering of the mouse in the terminal, the most famous being the output of ``ls -l``
    which may have the mouse looks like it sees hyperlinks on the terminal everywhere. Click does
    nothing but its an annoying limitation.
  * New Features:
  - New "start at login" option in the settings (only for GNOME) #251
  - Add ``--verbose``/``-v`` parameter to enable debug logging. Please note the existing ``-v`` (for
    version number) has been renamed ``-V``.
  - Support for hyperlink VTE extension (`described
    here <https://gist.github.com/egmontkob/eb114294efbcd5adb1944c9f3cb5feda>`__ ) #945 (Untested, as
    it requires VTE 0.50)
  - Add great color palettes from `Guake Color
    Scheme <https://github.com/ziyenano/Guake-Color-Schemes>
  - Allow application to capture right click (ex: Midnight commander). #1096. It is still possible to
    show the contextual menu with Shift+right click.
  * Bug Fixes:
  - delete tab even without libutempter (#1198)
  - Fix crash when changing command file #1229
  - fix ``import sys`` in ``simplegladeapp.py``
  - change scope of ``which_align`` variable in ``pref.py`` (#1225)
  - Fix user interface translations #1228
  - Fix several issues on Quick Edit:
  - There might be broken translations, or not up-to-date language support by Guake. A global refresh
    of all existing translations would be welcomed. Most has not been updated since the transition to
    Guake 3, so these languages support might probably be unfunctional or at least partialy
    localized.
- remove fix-simplegladeapp.patch, merged upstream
* Fri Mar 30 2018 sebix+novell.com@sebix.at
- initial package for version 3.0.5
- add fix-simplegladeapp.patch to fix runtime bug
